@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.010005'; # VERSION
+our $VERSION = '0.010006'; # VERSION
 
 1;
 
@@ -21,7 +21,7 @@ Business::CyberSource - Perl interface to the CyberSource Simple Order SOAP API
 
 =head1 VERSION
 
-version 0.010005
+version 0.010006
 
 =head1 DESCRIPTION
 
@@ -141,7 +141,7 @@ someone is using C<die> on a string.
 	}
 	catch {
 		my $e = $_;
-		sif ( $e->$_does('Business::CyberSource::Response::Role::Base') )
+		if ( $e->$_does('Business::CyberSource::Response::Role::Base')) {
 			carp $e->reason_code . $e->reason_text;
 		}
 		elsif ( $e->$_isa( $e_ns . '::SOAPFault'  ) ) {
@@ -262,8 +262,6 @@ feature.
 
 =head1 CONTRIBUTORS
 
-=for stopwords Carl Carstenson Robert Stone
-
 =over 4
 
 =item *
@@ -272,6 +270,10 @@ Carl Carstenson <ccarstenson@hostgator.com>
 
 =item *
 
+Carl Lantz <carl.lantz@endurance.com>
+
+=item *
+
 Robert Stone <robertstone@hostgator.com>
 
 =back
@@ -282,7 +284,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2015 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
