@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010005'; # VERSION
+our $VERSION = '0.010006'; # VERSION
 
 use Moose;
 with 'MooseY::RemoteHelper::Role::Client';
@@ -72,7 +72,7 @@ sub submit { ## no critic ( Subroutines::RequireArgUnpacking )
 	}
 
 	if ( $self->debug >= 1 ) {
-		Carp::carp( 'RESPONSE HASH: ' . Dumper( $answer->{result} ) );
+		Carp::carp( 'RESPONSE HASH: ' . Dumper( $answer ) );
 	}
 
 	return $self->_response_factory->create( $answer->{result}, $request );
@@ -270,7 +270,7 @@ Business::CyberSource::Client - User Agent Responsible for transmitting the Resp
 
 =head1 VERSION
 
-version 0.010005
+version 0.010006
 
 =head1 SYNOPSIS
 
@@ -388,7 +388,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2015 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
